/** 
 * Copyright (C) 2009 "Darwin V. Felix" <darwinfelix@users.sourceforge.net>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

package net.sf.spnego.example;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.web.servlet.FilterRegistrationBean;
import org.springframework.boot.web.servlet.support.SpringBootServletInitializer;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;

import net.sourceforge.spnego.SpnegoHttpFilter;

@ComponentScan({ "net.sf.spnego.example.*" })
@SpringBootApplication
public class HelloApplication extends SpringBootServletInitializer {
    
    @Value("${spnego.krb5.conf}")
    private String krb5Conf;
    
    @Value("${spnego.login.conf}")
    private String loginConf;
    
    @Value("${spnego.login.server.module}")
    private String serverModule;
    
    @Value("${spnego.login.client.module}")
    private String clientModule;
    
    @Value("${spnego.preauth.username}")
    private String preauthUsername;
    
    @Value("${spnego.preauth.password}")
    private String preauthPassword;
    
    @Value("${spnego.allow.basic}")
    private String allowBasic;
    
    @Value("${spnego.allow.unsecure.basic}")
    private String allowUnsecureBasic;
    
    @Value("${spnego.allow.localhost}")
    private String allowLocalhost;
    
    @Value("${spnego.prompt.ntlm}")
    private String promptNtlm;
    
    @Value("${spnego.exclude.dirs}")
    private String excludeDirs;
    
    @Value("${spnego.logger.level}")
    private String loggerLevel;
    
    // web servlet filter mapping - comma delimited (no spaces)
    private String servletFilterMappings = "/*";
    
    @Bean
    public FilterRegistrationBean<SpnegoHttpFilter> spnegoFilterRegistrationBean() {
        FilterRegistrationBean<SpnegoHttpFilter> register = new FilterRegistrationBean<>(new SpnegoHttpFilter());
        register.setName("SpnegoHttpFilter");
        
        // required
        register.addInitParameter("spnego.krb5.conf", this.krb5Conf);
        register.addInitParameter("spnego.login.conf", this.loginConf);
        register.addInitParameter("spnego.login.server.module", this.serverModule);
        register.addInitParameter("spnego.login.client.module", this.clientModule);
        register.addInitParameter("spnego.preauth.username", this.preauthUsername);
        register.addInitParameter("spnego.preauth.password", this.preauthPassword);
        register.addInitParameter("spnego.allow.basic", this.allowBasic);
        register.addInitParameter("spnego.allow.unsecure.basic", this.allowUnsecureBasic);
        register.addInitParameter("spnego.allow.localhost", this.allowLocalhost);
        register.addInitParameter("spnego.prompt.ntlm", this.promptNtlm);
        register.addInitParameter("spnego.exclude.dirs", this.excludeDirs);
        register.addInitParameter("spnego.logger.level", this.loggerLevel);
        
        // filter mapping(s)
        register.addUrlPatterns(this.servletFilterMappings); // comma delimited (no spaces)
        register.setOrder(1);

        return register;
    }
    
    public static void main(String[] args) {
        SpringApplication.run(HelloApplication.class, args);
    }
}
